@@ -1,12 +1,12 @@
 context('show_missing_packages')
 
 test_that('missing packages are found', {
-  filename <- '/test_source_show_missing_packages.R'
+  filename <- 'test_source_show_missing_packages.R'
   test_dir <- 'show_missing_packages'
   temp_dir <- tempdir()
-  testpath <- paste0(temp_dir, test_dir)
-  filepath <- paste0(testpath, filename)
-  dir.create(paste0(temp_dir, test_dir))
+  testpath <- file.path(temp_dir, test_dir)
+  filepath <- file.path(testpath, filename)
+  dir.create(testpath)
 
   con <- file(filepath)
   test_source <- 'library(dplyr666)
@@ -14,7 +14,14 @@ test_that('missing packages are found', {
   dplyr667::filter()
   require(dplyr668)'
   writeLines(text = test_source, con = con)
-  result <- show_missing_packages(path = testpath, repos = 'http://cran.rstudio.com/')
+
+  # check if repo is set, otherwise test is going to fail...
+  repo <- getOption("repos")
+  if (is.null(repo) | repo == '@CRAN@') {
+    repo <- 'https://cloud.R-project.org'
+  }
+
+  result <- show_missing_packages(path = testpath, repos = repo)
   close(con)
 
   expect_equal(nrow(result), 3)
